/*----------------------------------------*\
|                                          |
| >>AGBMIDI 1.0                            |
|                                          |
\*----------------------------------------*/

//! Am10_Init
//! ---------
//! Call this once at startup to start
//! DMA and setup sound.

void Am10_Init(void);

//! Am10_Main
//! ---------
//! Call this once every frame.
//! Timing is not critical as long as it
//! happens every frame.

void Am10_Main(void);

//! Am10_VBlank
//! ------------
//! Call this as soon as v-blank fires.
//! Timing is *critical*, therefore, it's
//! best to install in an interrupt routine.
//!
//! The call is *extremely* short, so there's no
//! need to worry about timing. (It's ~60 cycles
//! at most)

void Am10_VBlank(void);

//! Am10_SetMode
//! ------------
//! Call this to change the mixing frequency.
//!
//! int Mode
//!  Operation mode. Values are:
//!   -0 for 10512Hz
//!   -1 for 11468Hz
//!   -2 for 13379Hz
//!   -3 for 18157Hz
//!   -4 for 20068Hz
//!   -5 for 21024Hz
//!   -6 for 26758Hz
//!   -7 for 31536Hz

void Am10_SetMode(int Mode);

//! Am10_PlaySFX
//! ------------
//! Call this function to play an SFX on
//! an in-active channel or the quietest.
//! Will return the channel the SFX is
//! playing on.
//!
//! const void *Sample
//!  Pointer to sample data in the format of...
//!   short type; //Unused
//!   short stat; //0: One-shot sample, 4000h: Looped sample
//!   int   freq; //Frequency in 10Q form
//!   int   loop; //Loop start
//!   int   size; //Size (in bytes) of sample
//!
//!   byte  data[];
//!
//! int Volume
//!  Play the sample at this volume. (Range: 0..127)

int Am10_PlaySFX(const void *Sample, int Volume);

//! Am10_PlaySong
//! -------------
//! Call this to play a song.
//!
//! int Volume
//!  Plays song at this volume
//!
//! int Player
//!  The player to start
//!
//! const void *Song
//!  Pointer to song.
//!  Externs should be created with
//!  conversion program.

void Am10_PlaySong(int Volume, int Player, const void *Song);

//! Am10_StopSong
//! -------------
//! Call this to stop a song.
//!
//! int Player
//!  The player to stop

void Am10_StopSong(int Player);
